@@ -12,9 +12,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from oslo_config import cfg
 from oslo_policy import policy
 
-from monasca_log_api.policies import CHECK_AUTHORIZED_ROLES
+from monasca_log_api import policies
+
+CHECK_AUTHORIZED_ROLES = policies.roles_list_to_check_str(
+    cfg.CONF.roles_middleware.check_roles)
 
 rules = [
     policy.DocumentedRuleDefault(
@@ -22,7 +26,7 @@ rules = [
         check_str=CHECK_AUTHORIZED_ROLES,
         description='Healthcheck head rule',
         operations=[
-            {'path': '/', 'method': 'HEAD'}
+            {'path': '/healthcheck', 'method': 'HEAD'}
         ]
     ),
     policy.DocumentedRuleDefault(
@@ -30,7 +34,7 @@ rules = [
         check_str=CHECK_AUTHORIZED_ROLES,
         description='Healthcheck get rule',
         operations=[
-            {'path': '/', 'method': 'GET'}
+            {'path': '/healthcheck', 'method': 'GET'}
         ]
     ),
 ]
