@@ -39,24 +39,6 @@ from monasca_log_api import policies
 policy.POLICIES = policies
 
 
-class MockedAPI(falcon.API):
-    """MockedAPI
-
-    Subclasses :py:class:`falcon.API` in order to overwrite
-    request_type property with custom :py:class:`request.Request`
-
-    """
-
-    def __init__(self):
-        super(MockedAPI, self).__init__(
-            media_type=falcon.DEFAULT_MEDIA_TYPE,
-            request_type=request.Request,
-            response_type=falcon.Response,
-            middleware=None,
-            router=None
-        )
-
-
 def generate_unique_message(size):
     letters = string.ascii_letters
 
@@ -214,5 +196,12 @@ class BaseTestCase(oslotest_base.BaseTestCase):
             config.CONF.set_default(k, v, group)
 
 
-class BaseApiTestCase(BaseTestCase, testing.TestBase):
-    api_class = MockedAPI
+class BaseApiTestCase(BaseTestCase, testing.TestCase):
+
+    def setUp(self):
+        super(BaseApiTestCase, self).setUp()
+        self.app = falcon.API(request_type=request.Request)
+        # NOTE(czarneckia): Falcon 2.0.0 switches the default for this from True
+        # to False so we explicitly set it here to prevent the behaviour
+        # changing between versions.
+        self.app.req_options.strip_url_path_trailing_slash = True
